![Logo](logo.png)

# nheatmap
Inspired by pheatmap in R, this plotting tool aims to enable multi-level heatmap with the option to perform hierarchical clustering. The goal is to develop a package that is both intuitive in usage and extensive in plotting configuration.
    
![Example](./examples/example1.png)

## Requirements
    -Currently only

## Installation
    For now, use git clone and add the git package to the python path. Will be adding this to pypi package manager very soon.
    ```bash
    git clone https://github.com/xuesoso/nheatmap
    ```

## Usage

## Help

